pop

Function pop 

pub fn pop(path: &mut String) -> Option<String>
Removes the last component from the path and returns it.

If the path is a root or empty path, this function does nothing and returns None.