pub fn resolve(path: &mut String) -> Result<(), WorkingPathError>Expand description
Resolves the given path into an absolute, normalized path.
pub fn resolve(path: &mut String) -> Result<(), WorkingPathError>Resolves the given path into an absolute, normalized path.