macro_rules! normalize {
($($args:tt)*) => { ... };
}Expand description
Joins multiple paths together and then normalizes the result.
macro_rules! normalize {
($($args:tt)*) => { ... };
}Joins multiple paths together and then normalizes the result.